@@ -14,10 +14,6 @@
 #define __mxml2MsrTranslatorInterface__
 
 
-#ifdef VC6
-# pragma warning (disable : 4786)
-#endif
-
 #include <iostream>
 
 #include "exports.h"
@@ -26,38 +22,38 @@
 
 #include "messagesHandling.h"
 
-#include "msrOptions.h"
-
 #include "msr.h"
 
+#include "msrOah.h"
 
-namespace MusicXML2 
+
+namespace MusicXML2
 {
 
 //______________________________________________________________________________
 EXP void populateMsrSkeletonFromMxmlTree (
-  S_msrOptions&    msrOpts,
+  S_msrOah&    msrOpts,
   Sxmlelement      mxmlTree,
   S_msrScore       scoreSkeleton,
-  indentedOstream& logIOstream);
+  indentedOstream& logOstream);
 
 //______________________________________________________________________________
 EXP void displayMSRPopulatedScore (
-  S_msrOptions&    msrOpts,
+  S_msrOah&    msrOpts,
   S_msrScore       mScore,
-  indentedOstream& logIOstream);
+  indentedOstream& logOstream);
 
 //______________________________________________________________________________
 EXP void displayMSRPopulatedScoreSummary (
-  S_msrOptions&    msrOpts,
+  S_msrOah&    msrOpts,
   S_msrScore       mScore,
-  indentedOstream& logIOstream);
+  indentedOstream& logOstream);
 
 //______________________________________________________________________________
 EXP void displayMSRPopulatedScoreNames (
-  S_msrOptions&    msrOpts,
+  S_msrOah&    msrOpts,
   S_msrScore       mScore,
-  indentedOstream& logIOstream);
+  indentedOstream& logOstream);
 
 
 } // namespace MusicXML2
